# <img src='https://0000.us/klatchat/app/files/neon_images/icons/neon_skill.png' card_color="#FF8600" width="50" style="vertical-align:bottom">Data Controls
## Summary
Manage user data

## Description
Manage saved transcriptions and other user-generated media.

## Examples
- Clear my user transcriptions.
- Erase all pictures.
- Delete my profile.

## Contact Support
Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits

[NeonGeckoCom](https://github.com/NeonGeckoCom)
[NeonDaniel](https://github.com/NeonDaniel)

## Category
**Configuration**

## Tags
#NeonGecko Original
#NeonAI
#Data
#Settings
#Privacy
#Profile